==> nextcloud-15.0.5p1.tgz: nextcloud/apps/systemtags/l10n/nl.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Markering",
    "Update" : "Update",
    "Create" : "Opslaan",
    "Select tag…" : "Selecteren markering…",
    "System tag %1$s added by the system" : "Systeemtag %1$s toegevoegd door het systeem",
    "Added system tag {systemtag}" : "Voegde systeemtag {systemtag} toe",
    "Added system tag %1$s" : "Systeemtag %1$s toegevoegd",
    "%1$s added system tag %2$s" : "%1$s voegde systeemtag %2$s toe",
    "{actor} added system tag {systemtag}" : "{actor} voegde systeemtag {systemtag} toe",
    "System tag %1$s removed by the system" : "Systeemtag %1$s verwijderd door het systeem",
    "Removed system tag {systemtag}" : "Verwijderde systeemtag {systemtag}",
    "Removed system tag %1$s" : "Verwijderde systeemtag %1$s",
    "%1$s removed system tag %2$s" : "%1$s verwijderde systeemtag %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} verwijderde systeemtag {systemtag}",
    "You created system tag %1$s" : "Je creëerde systeemtag %1$s",
    "You created system tag {systemtag}" : "Je creëerde systeemtag {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creëerde systeemmarkering %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creëerde systeemtag {systemtag}",
    "You deleted system tag %1$s" : "Je verwijderde systeemtag %1$s",
    "You deleted system tag {systemtag}" : "Je verwijderde systeemtag {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s verwijderde systeem markering %2$s van het systeem",
    "{actor} deleted system tag {systemtag}" : "{actor} verwijderde systeemtag {systemtag}",
    "You updated system tag %2$s to %1$s" : "Je werkte systeemtag %2$s bij naar  %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Je werkte systeemtag {oldsystemtag} bij naar {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hernoemde systeem markering %3$s naar %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} werkte systeemtag {oldsystemtag} bij naar {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systeemtag %2$s door systeem toegevoegd aan %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Systeemtag {systemtag} is door het systeem toegevoegd aan bestand {file}",
    "You added system tag %2$s to %1$s" : "Je voegde systeemtag %2$s toe aan %1$s",
    "You added system tag {systemtag} to {file}" : "Je voegde systeemtag {systemtag} toe aan {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s voegde systeemtag %3$s toe aan %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} voegde systeemtag {systemtag} toe aan {file}",
    "System tag %2$s was removed from %1$s by the system" : "Systeemtag %2$s door het systeem verwijderd van %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "Systeemtag {systemtag} door het systeem verwijderd van {file}",
    "You removed system tag %2$s from %1$s" : "Je verwijderde systeemtag %2$s van %1$s",
    "You removed system tag {systemtag} from {file}" : "Verwijderde systeemtag {systemtag} van {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s verwijderde systeemtag %3$s van %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} verwijderde systeemtag {systemtag} van {file}",
    "%s (restricted)" : "%s (beperkt)",
    "%s (invisible)" : "%s (onzichtbaar)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systeemmarkeringen</strong> voor een bestand zijn gewijzigd",
    "Collaborative tags" : "Systeemtags",
    "Collaborative tagging functionality which shares tags among users." : "Samenwerkings tagfunctionaliteit, waardoor je tags kunt delen onder gebruikers.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Samenwerkings tagfunctionaliteit, waardoor je tags kunt delen onder gebruikers. Perfect voor teams\n(als je een provider met een multi-tenancy installatie bent, adviseren we om deze app uit te schakelen omdat tags worden gedeeld.)",
    "Tagged files" : "Gemarkeerde bestanden",
    "Select tags to filter by" : "Selecteer markering om op te filteren",
    "No tags found" : "Geen tags gevonden",
    "Please select tags to filter by" : "Selecteer markeringen om op te filteren",
    "No files found for the selected tags" : "Geen bestanden gevonden voor de geselecteerde markeringen",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samenwerkingstags zijn beschikbaar voor alle gebruikers. Beperkte tags zijn zichtbaar voor gebruikers, maar kunnen niet door hen worden toegewezen. Onzichtbare tags zijn er alleen voor intern gebruik, aangezien gebruikers ze niet kunnen zien of toewijzen.",
    "Select tag …" : "Selecteer tag …",
    "Create a new tag" : "Creëren nieuw tag",
    "Name" : "Tag",
    "Public" : "Standaard",
    "Restricted" : "Beschermd",
    "Invisible" : "Verborgen",
    "Delete" : "Verwijder",
    "Reset" : "Herstellen",
    "No files in here" : "Hier geen bestanden",
    "No entries found in this folder" : "Niets gevonden in deze map",
    "Size" : "Grootte",
    "Modified" : "Aangepast",
    "Create and edit collaborative tags. These tags affect all users." : "Maak en bewerk systeemtags. Deze tags raken alle gebruikers."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.3.tgz: nextcloud/apps/systemtags/l10n/nl.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Markering",
    "Tag name is empty" : "Markeringsnaam is niet ingevuld",
    "Update" : "Update",
    "Create" : "Opslaan",
    "Select tag…" : "Selecteren markering…",
    "System tag %1$s added by the system" : "Systeemtag %1$s toegevoegd door het systeem",
    "Added system tag {systemtag}" : "Voegde systeemtag {systemtag} toe",
    "Added system tag %1$s" : "Systeemtag %1$s toegevoegd",
    "%1$s added system tag %2$s" : "%1$s voegde systeemtag %2$s toe",
    "{actor} added system tag {systemtag}" : "{actor} voegde systeemtag {systemtag} toe",
    "System tag %1$s removed by the system" : "Systeemtag %1$s verwijderd door het systeem",
    "Removed system tag {systemtag}" : "Verwijderde systeemtag {systemtag}",
    "Removed system tag %1$s" : "Verwijderde systeemtag %1$s",
    "%1$s removed system tag %2$s" : "%1$s verwijderde systeemtag %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} verwijderde systeemtag {systemtag}",
    "You created system tag %1$s" : "Je creëerde systeemtag %1$s",
    "You created system tag {systemtag}" : "Je creëerde systeemtag {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creëerde systeemmarkering %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creëerde systeemtag {systemtag}",
    "You deleted system tag %1$s" : "Je verwijderde systeemtag %1$s",
    "You deleted system tag {systemtag}" : "Je verwijderde systeemtag {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s verwijderde systeem markering %2$s van het systeem",
    "{actor} deleted system tag {systemtag}" : "{actor} verwijderde systeemtag {systemtag}",
    "You updated system tag %2$s to %1$s" : "Je werkte systeemtag %2$s bij naar  %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Je werkte systeemtag {oldsystemtag} bij naar {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s hernoemde systeem markering %3$s naar %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} werkte systeemtag {oldsystemtag} bij naar {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systeemtag %2$s door systeem toegevoegd aan %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Systeemtag {systemtag} is door het systeem toegevoegd aan bestand {file}",
    "You added system tag %2$s to %1$s" : "Je voegde systeemtag %2$s toe aan %1$s",
    "You added system tag {systemtag} to {file}" : "Je voegde systeemtag {systemtag} toe aan {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s voegde systeemtag %3$s toe aan %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} voegde systeemtag {systemtag} toe aan {file}",
    "System tag %2$s was removed from %1$s by the system" : "Systeemtag %2$s door het systeem verwijderd van %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "Systeemtag {systemtag} door het systeem verwijderd van {file}",
    "You removed system tag %2$s from %1$s" : "Je verwijderde systeemtag %2$s van %1$s",
    "You removed system tag {systemtag} from {file}" : "Verwijderde systeemtag {systemtag} van {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s verwijderde systeemtag %3$s van %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} verwijderde systeemtag {systemtag} van {file}",
    "%s (restricted)" : "%s (beperkt)",
    "%s (invisible)" : "%s (onzichtbaar)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systeemmarkeringen</strong> voor een bestand zijn gewijzigd",
    "Collaborative tags" : "Systeemtags",
    "Collaborative tagging functionality which shares tags among users." : "Samenwerkings tagfunctionaliteit, waardoor je tags kunt delen onder gebruikers.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Samenwerkings tagfunctionaliteit, waardoor je tags kunt delen onder gebruikers. Perfect voor teams\n(als je een provider met een multi-tenancy installatie bent, adviseren we om deze app uit te schakelen omdat tags worden gedeeld.)",
    "Tagged files" : "Gemarkeerde bestanden",
    "Select tags to filter by" : "Selecteer markering om op te filteren",
    "No tags found" : "Geen tags gevonden",
    "Please select tags to filter by" : "Selecteer markeringen om op te filteren",
    "No files found for the selected tags" : "Geen bestanden gevonden voor de geselecteerde markeringen",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samenwerkingstags zijn beschikbaar voor alle gebruikers. Beperkte tags zijn zichtbaar voor gebruikers, maar kunnen niet door hen worden toegewezen. Onzichtbare tags zijn er alleen voor intern gebruik, aangezien gebruikers ze niet kunnen zien of toewijzen.",
    "Select tag …" : "Selecteer tag …",
    "Create a new tag" : "Creëren nieuw tag",
    "Name" : "Tag",
    "Public" : "Standaard",
    "Restricted" : "Beschermd",
    "Invisible" : "Verborgen",
    "Delete" : "Verwijder",
    "Reset" : "Herstellen",
    "No files in here" : "Hier geen bestanden",
    "No entries found in this folder" : "Niets gevonden in deze map",
    "Size" : "Grootte",
    "Modified" : "Aangepast"
},
"nplurals=2; plural=(n != 1);");
